--- Aurora - Extension
--- Copyright (c) 2019-2021, Marouan Sabbagh <mar.sabbagh@gmail.com>
--- All Rights Reserved.
---
--- This file is part of addon Aurora - Extension.

local _, AE = ...

-- WoW API
local _G = _G

-- Aurora API
if not _G.Aurora then return end
local Hook = _G.Aurora.Hook
local Skin = _G.Aurora.Skin

local function RemoveCropIcon(texture, parent)
    texture:SetTexCoord(0, 1, 0, 1)
    if parent then
        select(-1, parent:GetRegions()):Hide()
    end
end

local function DisableSkin_EncounterJournal_SuggestedContent()
    if _G.AuroraExtensionDB.skinEncounterJournalSuggestedContent then return end

    Hook.EJSuggestFrame_UpdateRewards = function() end
    Hook.EJSuggestFrame_RefreshDisplay = function() end

    Skin.AdventureJournal_SecondaryTemplate = function() end

    local bck_Skin_UIPanelButtonTemplate = Skin.UIPanelButtonTemplate
    function Skin.UIPanelButtonTemplate(button)
        if EncounterJournal and button == EncounterJournal.suggestFrame.Suggestion1.button then return end
        bck_Skin_UIPanelButtonTemplate(button)
    end

    local bck_Skin_NavButtonPrevious = Skin.NavButtonPrevious
    function Skin.NavButtonPrevious(button)
        if EncounterJournal and button == EncounterJournal.suggestFrame.Suggestion1.prevButton then return end
        bck_Skin_NavButtonPrevious(button)
    end

    local bck_Skin_NavButtonNext = Skin.NavButtonNext
    function Skin.NavButtonNext(button)
        if EncounterJournal and button == EncounterJournal.suggestFrame.Suggestion1.nextButton then return end
        bck_Skin_NavButtonNext(button)
    end
end

local function DisableSkin_EncounterJournal_SuggestedContent_OnLoad()
    if _G.AuroraExtensionDB.skinEncounterJournalSuggestedContent then return end

    local EncounterJournal = _G.EncounterJournal

    -- Suggested Content
    local suggestFrame = EncounterJournal.suggestFrame
    local Suggestion1 = suggestFrame.Suggestion1

    Suggestion1.bg:Show()
    Suggestion1:SetBackdrop(nil)

    Suggestion1.iconRing:SetAlpha(1)
    RemoveCropIcon(Suggestion1.icon, Suggestion1)
    Suggestion1.icon:SetMask("Interface\\CharacterFrame\\TempPortraitAlphaMask")

    Suggestion1.centerDisplay.title.text:SetTextColor(0, 0, 0)
    Suggestion1.centerDisplay.description.text:SetTextColor(0.2824, 0.0157, 0.0157)

    Suggestion1.reward.text:SetTextColor(0.2824, 0.0157, 0.0157)
    Suggestion1.reward.iconRingHighlight:SetAlpha(1)
    Suggestion1.reward.iconRing:SetAlpha(1)
    RemoveCropIcon(Suggestion1.reward.icon, Suggestion1.reward)
    Suggestion1.reward.icon:SetMask("Interface\\CharacterFrame\\TempPortraitAlphaMask")

    -- Tooltip
    local tooltip = _G.EncounterJournalTooltip
    RemoveCropIcon(tooltip.Item1.icon)
    tooltip.Item1:SetBackdrop(nil)
    tooltip.Item1._auroraIconBorder = nil
    RemoveCropIcon(tooltip.Item2.icon)
    tooltip.Item2:SetBackdrop(nil)
    tooltip.Item2._auroraIconBorder = nil
end

function AE.addons.Blizzard_EncounterJournal()
    DisableSkin_EncounterJournal_SuggestedContent()
end

function AE.onload.Blizzard_EncounterJournal()
    DisableSkin_EncounterJournal_SuggestedContent_OnLoad()
end

AE.AddOption("checkbox", "Adventure Guide - Suggested Content", "skinEncounterJournalSuggestedContent", true)