--- Aurora - Extension
--- Copyright (c) 2019-2021, Marouan Sabbagh <mar.sabbagh@gmail.com>
--- All Rights Reserved.
---
--- This file is part of addon Aurora - Extension.

local _, AE = ...

-- WoW API
local _G = _G

-- Aurora API
if not _G.Aurora then return end
local Hook = _G.Aurora.Hook
local Skin = _G.Aurora.Skin

local function DisableSkin_ObjectiveTracker()
    if _G.AuroraExtensionDB.skinObjectiveTracker then return end

    Hook.QuestObjectiveItem_Initialize = function() end
    Hook.QuestObjectiveSetupBlockButton_AddRightButton = function() end
    Hook.DEFAULT_OBJECTIVE_TRACKER_MODULE.AddObjective = function() end
    Hook.DEFAULT_OBJECTIVE_TRACKER_MODULE.AddTimerBar = function() end
    Hook.DEFAULT_OBJECTIVE_TRACKER_MODULE.AddProgressBar = function() end
    Hook.ObjectiveTracker_Initialize = function() end
    Hook.ObjectiveTrackerMinimizeButtonMixin.SetCollapsed = function() end
    Hook.AUTO_QUEST_POPUP_TRACKER_MODULE.Update = function() end
    Hook.BonusObjectiveTrackerModuleMixin.AddProgressBar = function() end
    Hook.SCENARIO_TRACKER_MODULE.AddProgressBar = function() end
    Hook.ScenarioStage_CustomizeBlock = function() end

    Skin.QuestObjectiveItemButtonTemplate = function() end
    Skin.QuestObjectiveFindGroupButtonTemplate = function() end
    Skin.ObjectiveTrackerMinimizeButtonTemplate = function() end
    Skin.ObjectiveTrackerHeaderTemplate = function() end
    Skin.ObjectiveTrackerTimerBarTemplate = function() end
    Skin.ObjectiveTrackerProgressBarTemplate = function() end
    Skin.QuestObjectiveAnimLineTemplate = function() end
    Skin.AutoQuestPopUpBlockTemplate = function() end
    Skin.BonusObjectiveTrackerLineTemplate = function() end
    Skin.BonusObjectiveTrackerHeaderTemplate = function() end
    Skin.BonusTrackerProgressBarTemplate = function() end
    Skin.ScenarioTrackerProgressBarTemplate = function() end

    -- Blizzard_UIWidgets
    Skin.UIWidgetBaseScenarioHeaderTemplate = function() end
    local bck_Skin_UIWidgetTemplateStatusBar = Skin.UIWidgetTemplateStatusBar
    function Skin.UIWidgetTemplateStatusBar(Frame)
        if Frame:GetParent().widgetSetID ~= 514 then  -- Jailers Tower Bar
            bck_Skin_UIWidgetTemplateStatusBar(Frame)
        end
    end

    -- Blizzard_MawBuffs
    Skin.MawBuffsContainer = function() end
end

local function DisableSkin_ObjectiveTracker_OnLoad()
    if _G.AuroraExtensionDB.skinObjectiveTracker then return end

    -- Scenario
    if ScenarioStageBlock._auroraBG then
        ScenarioStageBlock._auroraBG:Hide()
        ScenarioStageBlock.NormalBG:Show()
    end

    -- Challenge Mode
    local bg = select(3, ScenarioChallengeModeBlock:GetRegions())
    bg:Show()
    ScenarioChallengeModeBlock.TimerBGBack:Show()
    ScenarioChallengeModeBlock.TimerBG:Show()
end

function AE.addons.Blizzard_ObjectiveTracker()
    DisableSkin_ObjectiveTracker()
end

function AE.onload.Blizzard_ObjectiveTracker()
    DisableSkin_ObjectiveTracker_OnLoad()
end

AE.AddOption("checkbox", "Objective Tracker", "skinObjectiveTracker", true)