--- Aurora - Extension
--- Copyright (c) 2019-2021, Marouan Sabbagh <mar.sabbagh@gmail.com>
--- All Rights Reserved.
---
--- This file is part of addon Aurora - Extension.

local addonName, AE = ...

-- WoW API
local _G = _G

-- Aurora API
if not _G.Aurora then return end
local Skin = _G.Aurora.Skin

local cBold = "|cff00ffe3"
local options = {}

AE.addons = {}
AE.onload = {}

-- Options
local createToggleBox do
    local function toggle(self)
        _G.AuroraExtensionDB[self.value] = self:GetChecked()
    end

    function createToggleBox(parent, value, text)
        local checkbutton = CreateFrame("CheckButton", nil, parent, "InterfaceOptionsCheckButtonTemplate")
        checkbutton.Text:SetText(text)
        checkbutton.value = value
        checkbutton:SetScript("OnClick", toggle)
        AE.SetOptionObject(value, checkbutton)
        return checkbutton
    end
end

local createButton do
    function createButton(parent, func, text)
        local button = CreateFrame("Button", nil, parent, "OptionsButtonTemplate")
        button:SetText(text)
        button:SetScript("OnClick", function(self)
            func()
        end)
        return button
    end
end

local function CreateOptions()
    -- Defaults
    if _G.AuroraExtensionDB then
        for _, option in ipairs(options) do
            if _G.AuroraExtensionDB[option.key] == nil then
                if type(option.default) == "table" then
                    _G.AuroraExtensionDB[option.key] = {}
                    for k, v in option.default do
                        _G.AuroraExtensionDB[option.key][k] = v
                    end
                else
                    _G.AuroraExtensionDB[option.key] = option.default
                end
            end
        end
    else
        _G.AuroraExtensionDB = {}
        for _, option in ipairs(options) do
            _G.AuroraExtensionDB[option.key] = option.default
        end
    end

    -- Defaults Cleanup
    -- TODO: Remove it
    if _G.AuroraExtensionDB["skinAchievementItem"] ~= nil then
        _G.AuroraExtensionDB["skinAchievementsItem"] = _G.AuroraExtensionDB["skinAchievementItem"]
        _G.AuroraExtensionDB["skinAchievementItem"] = nil
    end

    -- GUI
    local optionsFrame = CreateFrame("Frame", addonName.."Options", _G.UIParent)
    optionsFrame.name = GetAddOnMetadata(addonName, "Title")
    optionsFrame.parent = _G.AuroraOptions and _G.AuroraOptions.name or nil
    _G.InterfaceOptions_AddCategory(optionsFrame)

    local title = optionsFrame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    title:SetPoint("TOPLEFT", 16, -16)
    title:SetText(optionsFrame.name.."  "..HIGHLIGHT_FONT_COLOR_CODE..GetAddOnMetadata(addonName, "Version"))

    local subText = optionsFrame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
    subText:SetHeight(32)
    subText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
    subText:SetJustifyH("LEFT")
    subText:SetJustifyV("TOP")
    local text = "This is advanced "..cBold.."Aurora|r options from addon "..cBold..GetAddOnMetadata(addonName, "Title").."|r. With these options, you can disable some Aurora\n"
    text = text.."settings. If you want additional Aurora options, please create ticket with feature request at ...\n"
    text = text..cBold.."https://www.curseforge.com/wow/addons/aurora-extension/issues|r"
    subText:SetText(text)

    local prevItem = subText
    for k, option in ipairs(options) do
        if option.type == "checkbox" then
            local item = createToggleBox(optionsFrame, option.key, option.name)
            item:SetPoint("TOPLEFT", prevItem, "BOTTOMLEFT", k == 1 and -2 or 0, -8)
            prevItem = item
        end
    end

    local reloadButton = createButton(optionsFrame, _G.C_UI.Reload, _G.RELOADUI)
    reloadButton:SetPoint("BOTTOMRIGHT", -20, 20)

    -- Set values
    optionsFrame.refresh = function()
        for _, option in ipairs(options) do
            if option.type == "checkbox" then
                option.object:SetChecked(_G.AuroraExtensionDB[option.key])
            end
        end
    end

    -- Aurora skin
    for _, option in ipairs(options) do
        if option.type == "checkbox" then
            Skin.InterfaceOptionsCheckButtonTemplate(option.object)
        end
    end
    Skin.OptionsButtonTemplate(reloadButton)

    -- Hook Aurora options
    if _G.AuroraOptions then
        hooksecurefunc("InterfaceOptionsListButton_OnClick", function(self, mouseButton)
            if self.element.name == "Aurora" and mouseButton ~= "RightButton" then
                if self.element.hasChildren and self.element.collapsed then
                    OptionsListButtonToggle_OnClick(self.toggle)
                end
            end
        end)
    end
end

function AE.AddOption(type, name, key, default)
    tinsert(options, {
        type = type,
        name = name,
        key = key,
        default = default
    })
end

function AE.SetOptionObject(key, object)
    for _, option in ipairs(options) do
        if option.key == key then
            option.object = object
            break
        end
    end
end

-- OnLoad
function AE.OnLoad()
    CreateOptions()

    for _, func in next, AE.addons do
        func()
    end
end

local eventFrame = CreateFrame("Frame")
eventFrame:SetScript("OnEvent", function(_, _, addon)
    if addon == addonName then
        AE.OnLoad()
    else
        if AE.onload[addon] then
            AE.onload[addon]()
        end
    end
end)
eventFrame:RegisterEvent("ADDON_LOADED")